@@ -1,6 +1,6 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:ft=tcl:et:sw=4:ts=4:sts=4
 # portmdmg.tcl
-# $Id: portmdmg.tcl 79597 2011-06-19 20:59:11Z jmr@macports.org $
+# $Id: portmdmg.tcl 101263 2013-01-07 13:54:16Z jmr@macports.org $
 #
 # Copyright (c) 2005, 2007-2011 The MacPorts Project
 # Copyright (c) 2003-2004 Apple Inc.
@@ -84,6 +84,12 @@ proc portmdmg::package_mdmg {portname portversion portrevision} {
         set subdev 2
     }
 
+    if {![file isdirectory $mpkgpath]} {
+        file mkdir ${package.destpath}/${imagename}
+        file copy $mpkgpath ${package.destpath}/${imagename}
+        set mpkgpath ${package.destpath}/${imagename}
+    }
+
     set hdiutil [findBinary hdiutil $portutil::autoconf::hdiutil_path]
     if {[system "$hdiutil create -quiet -fs HFS+ -volname ${imagename} -srcfolder ${mpkgpath} ${tmp_image}"] != ""} {
         return -code error [format [msgcat::mc "Failed to create temporary image: %s"] ${imagename}]
