@@ -1,7 +1,8 @@
 /*
  * rmd160cmd.c
- * $Id: rmd160cmd.c 53201 2009-07-01 05:46:54Z toby@macports.org $
+ * $Id: rmd160cmd.c 79593 2011-06-19 20:36:07Z jmr@macports.org $
  *
+ * Copyright (c) 2006, 2009-2011 The MacPorts Project
  * Copyright (c) 2005 Paul Guyot <pguyot@kallisys.net>.
  * All rights reserved.
  *
@@ -13,7 +14,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. Neither the name of Apple Computer, Inc. nor the names of its contributors
+ * 3. Neither the name of The MacPorts Project nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  * 
@@ -35,37 +36,38 @@
 #endif
 
 #include <string.h>
-
-#include <tcl.h>
-
-#include "rmd160cmd.h"
-
-#if !defined(HAVE_LIBMD)
-
-/* We do not have libmd.
- * let's use our own version of rmd160* libraries.
- */
 #include <stdio.h>
 #include <fcntl.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <errno.h>
 
-#include <sys/types.h>
+#include <tcl.h>
 
+#include "rmd160cmd.h"
+
+#if defined(HAVE_LIBMD) && defined(HAVE_RIPEMD_H)
+#include <sys/types.h>
+#include <ripemd.h>
+#elif defined(HAVE_LIBCRYPTO) && defined(HAVE_OPENSSL_RIPEMD_H)
+#include <openssl/ripemd.h>
+
+#include "md_wrappers.h"
+CHECKSUMEnd(RIPEMD160_, RIPEMD160_CTX, RIPEMD160_DIGEST_LENGTH)
+CHECKSUMFile(RIPEMD160_, RIPEMD160_CTX)
+#else
+/*
+ * let's use our own version of rmd160* libraries.
+ */
+#include <sys/types.h>
 #include "rmd160.h"
 #include "rmd160.c"
 #define RIPEMD160_DIGEST_LENGTH 20
+#define RIPEMD160_File(x,y) RMD160File(x,y)
+
 #include "md_wrappers.h"
 CHECKSUMEnd(RMD160, RMD160_CTX, RIPEMD160_DIGEST_LENGTH)
 CHECKSUMFile(RMD160, RMD160_CTX)
-
-#elif defined(HAVE_LIBMD)
-#include <sys/types.h>
-#include <ripemd.h>
-#define RMD160File(x, y) RIPEMD160_File(x, y)
-#else
-#error libcrypto or libmd are required
 #endif
 
 int RMD160Cmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
@@ -92,7 +94,7 @@ int RMD160Cmd(ClientData clientData UNUSED, Tcl_Interp *interp, int objc, Tcl_Ob
 	}
 	file = Tcl_GetString(objv[2]);
 
-	if (!RMD160File(file, buf)) {
+	if (!RIPEMD160_File(file, buf)) {
 		tcl_result = Tcl_NewStringObj(error_message, sizeof(error_message) - 1);
 		Tcl_AppendObjToObj(tcl_result, Tcl_NewStringObj(file, -1));
 		Tcl_SetObjResult(interp, tcl_result);
