@@ -4,7 +4,7 @@
 # helpful text and then delete this message.
 #
 # port-help.tcl
-# $Id: port-help.tcl 89466 2012-01-30 20:54:31Z jmr@macports.org $
+# $Id: port-help.tcl 101262 2013-01-07 13:49:04Z jmr@macports.org $
 
 
 set porthelp(activate) {
@@ -345,7 +345,14 @@ Unarchive the destroot of the given ports from installed images
 set porthelp(uninstall) {
 Uninstall the given ports
 
---no-exec   Do not execute any stored pre- or post-uninstall procedures
+--follow-dependents     Recursively uninstall all ports that depend on the
+                        specified port before uninstalling the port itself.
+--follow-dependencies   Also recursively uninstall all ports that the
+                        specified port depended on. This will not uninstall
+                        dependencies that are marked as requested or that
+                        have other dependents.
+--no-exec               Do not execute any stored pre- or post-uninstall
+                        procedures.
 }
 
 set porthelp(unload) $porthelp(load)
