@@ -1,6 +1,6 @@
 # -*- coding: utf-8; mode: tcl; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- vim:fenc=utf-8:ft=tcl:et:sw=4:ts=4:sts=4
 # portuninstall.tcl
-# $Id: portuninstall.tcl 79597 2011-06-19 20:59:11Z jmr@macports.org $
+# $Id: portuninstall.tcl 100223 2012-12-04 00:50:31Z cal@macports.org $
 #
 # Copyright (c) 2004-2005, 2008-2011 The MacPorts Project
 # Copyright (c) 2002 - 2003 Apple Inc.
@@ -215,9 +215,11 @@ proc uninstall {portname {version ""} {revision ""} {variants 0} {optionslist ""
         file delete $imagefile
         # Try to delete the port's image dir; will fail if there are more image
         # files so just ignore the failure
-        catch {file delete [file dirname $imagefile]}
+        catch {file delete [::file dirname $imagefile]}
 
-        registry::entry delete $port
+        registry::write {
+            registry::entry delete $port
+        }
     }
     
     # uninstall dependencies if requested
